@@ -24,8 +24,8 @@
 #include <KListWidget>
 #include <KLineEdit>
 #include <KEMailSettings>
-#include <kdebug.h>
-#include <kmessagebox.h>
+#include <KDebug>
+#include <KMessageBox>
 
 #include "ui_newclass.h"
 #include "ui_licensechooser.h"
@@ -47,79 +47,158 @@
 
 namespace KDevelop {
 
-class CreateClassWizardPrivate {
-public:
-
-   KUrl baseUrl;
-    OutputPage* output;
+struct CreateClassAssistantPrivate
+{
+    KUrl baseUrl;
     ClassGenerator * generator;
+    ClassIdentifierPage* classIdentifierPageWidget;
+    OverridesPage *overridesPageWidget;
+    LicensePage *licensePageWidget;
+    OutputPage* outputPageWidget;
+    KPageWidgetItem* classIdentifierPage;
+    KPageWidgetItem* overridesPage;
+    KPageWidgetItem* licensePage;
+    KPageWidgetItem* outputPage;
 };
 
-
-CreateClassWizard::CreateClassWizard(QWidget* parent, ClassGenerator * generator, KUrl baseUrl)
-    : QWizard(parent)
-    , d(new CreateClassWizardPrivate)
+CreateClassAssistant::CreateClassAssistant(QWidget* parent, ClassGenerator * generator, const KUrl& baseUrl)
+: KAssistantDialog(parent)
+, d(new CreateClassAssistantPrivate)
 {
     d->baseUrl = baseUrl;
     Q_ASSERT(generator);
     d->generator = generator;
-    
-    setDefaultProperty("KUrlRequester", "url", SIGNAL(textChanged(QString)));
-    setDefaultProperty("KTextEdit", "plainText", SIGNAL(textChanged()));
 }
 
-CreateClassWizard::~CreateClassWizard()
+CreateClassAssistant::~CreateClassAssistant()
 {
     delete d;
 }
 
-void CreateClassWizard::setup()
+void CreateClassAssistant::setup()
 {
     setWindowTitle(i18n("Create New Class in %1", d->baseUrl.prettyUrl()));
 
-    if (QWizardPage* page = newIdentifierPage())
-        addPage(page);
+    d->classIdentifierPageWidget = newIdentifierPage();
+    connect(d->classIdentifierPageWidget, SIGNAL(isValid(bool)), this, SLOT(checkClassIdentifierPage(bool)));
+    d->classIdentifierPage = addPage(d->classIdentifierPageWidget, i18n("Class Basics"));
+    d->classIdentifierPage->setIcon(KIcon("classnew"));
 
-    if (QWizardPage* page = newOverridesPage())
-        addPage(page);
+    d->overridesPageWidget = newOverridesPage();
+    d->overridesPage = addPage(d->overridesPageWidget, i18n("Override Methods"));
+    d->overridesPage->setIcon(KIcon("code-class"));
 
-    addPage(new LicensePage(this));
-    addPage(d->output = new OutputPage(this));
+    d->licensePageWidget = new LicensePage(this);
+    d->licensePage = addPage(d->licensePageWidget, i18n("License"));
+    d->licensePage->setIcon(KIcon("text-x-copying"));
+
+    d->outputPageWidget = new OutputPage(this);
+    connect(d->outputPageWidget, SIGNAL(isValid(bool)), this, SLOT(checkOutputPage(bool)));
+    d->outputPage = addPage(d->outputPageWidget, i18n("Output"));
+    d->outputPage->setIcon(KIcon("document-save"));
+
+    setValid(d->classIdentifierPage, false);
+    setValid(d->overridesPage, true);
+    setValid(d->licensePage, true);
+    setValid(d->outputPage, false);
+    showButton(KDialog::Help, false);
+
+    setCurrentPage(d->classIdentifierPage);
 }
 
-void CreateClassWizard::accept()
+void CreateClassAssistant::checkClassIdentifierPage(bool valid)
+{
+    setValid(d->classIdentifierPage, valid);
+}
+
+void CreateClassAssistant::checkOutputPage(bool valid)
+{
+    setValid(d->outputPage, valid);
+}
+
+bool CreateClassAssistant::validateClassIdentifierPage()
+{
+    generator()->setIdentifier(d->classIdentifierPageWidget->identifierLineEdit()->userText());
+
+    //Remove old base classes, and add the new ones
+    generator()->clearInheritance();
+    foreach (const QString& inherited, d->classIdentifierPageWidget->inheritanceList()) {
+        generator()->addBaseClass(inherited);
+    }
+
+    //Update the overrides page with the new inheritance list
+    d->overridesPageWidget->updateOverrideTree();
+
+    return true;
+}
+
+bool CreateClassAssistant::validateOverridesPage()
+{
+    d->overridesPageWidget->validateOverrideTree();
+    return true;
+}
+
+bool CreateClassAssistant::validateLicensePage()
+{
+    bool valid = d->licensePageWidget->validatePage();
+
+    if (valid) {
+        generator()->setLicense(d->licensePageWidget->licenseTextEdit()->toPlainText());
+        d->outputPageWidget->initializePage();
+    }
+
+    return valid;
+}
+
+bool CreateClassAssistant::validateOutputPage()
+{
+    d->outputPageWidget->validatePage();
+    return true;
+}
+
+void CreateClassAssistant::next()
+{
+    bool valid = false;
+
+    if (currentPage() == d->classIdentifierPage) {
+        valid = validateClassIdentifierPage();
+    } else if (currentPage() == d->overridesPage) {
+        valid = validateOverridesPage();
+    } else if (currentPage() == d->licensePage) {
+        valid = validateLicensePage();
+    }
+
+    if (valid) {
+        KAssistantDialog::next();
+    }
+}
+
+void CreateClassAssistant::accept()
 {
-    QWizard::accept();
-    
     //Transmit all the final information to the generator
-    d->generator->setLicense(field("license").toString());
-    kDebug() << "Header Url: " << field("headerUrl").toString();
-    /*
-    d->generator->setHeaderUrl(field("headerUrl").toString());
-    d->generator->setImplementationUrl(field("implementationUrl").toString());
-    d->generator->setHeaderPosition(SimpleCursor(field("headerLine").toInt(), field("headerColumn").toInt()));
-    d->generator->setHeaderPosition(SimpleCursor(field("implementationLine").toInt(), field("implementationColumn").toInt()));
-    */
+    validateOutputPage();
+
     DocumentChangeSet changes = d->generator->generate();
-    
     changes.setReplacementPolicy(DocumentChangeSet::WarnOnFailedChange);
     changes.setActivationPolicy(KDevelop::DocumentChangeSet::Activate);
     changes.applyAllChanges();
+
+    KAssistantDialog::accept();
 }
 
-ClassGenerator * CreateClassWizard::generator()
+ClassGenerator * CreateClassAssistant::generator()
 {
     return d->generator;
 }
 
-ClassIdentifierPage* CreateClassWizard::newIdentifierPage()
+ClassIdentifierPage* CreateClassAssistant::newIdentifierPage()
 {
     return new ClassIdentifierPage(this);
 }
 
-OverridesPage* CreateClassWizard::newOverridesPage()
+OverridesPage* CreateClassAssistant::newOverridesPage()
 {
-    return new OverridesPage(d->generator, this);
+    return new OverridesPage(generator(), this);
 }
 
 struct ClassGeneratorPrivate
@@ -129,13 +208,13 @@ struct ClassGeneratorPrivate
     QList<DeclarationPointer> inheritedClasses;   ///< Represent *ALL* of the inherited classes
     SimpleCursor headerPosition;
     SimpleCursor implementationPosition;
-    
+
     KUrl headerUrl;
     KUrl implementationUrl;
 };
 
-ClassGenerator::ClassGenerator() :
-                             d(new ClassGeneratorPrivate)
+ClassGenerator::ClassGenerator()
+: d(new ClassGeneratorPrivate)
 {
 }
 
@@ -144,12 +223,12 @@ ClassGenerator::~ClassGenerator()
     delete d;
 }
 
-const QString & ClassGenerator::name() const
+QString ClassGenerator::name() const
 {
     return d->name;
 }
 
-void ClassGenerator::setName(const QString & newName)
+void ClassGenerator::setName(const QString& newName)
 {
     d->name = newName;
 }
@@ -159,28 +238,28 @@ QString ClassGenerator::identifier() const
     return name();
 }
 
-void ClassGenerator::setIdentifier(const QString & identifier)
+void ClassGenerator::setIdentifier(const QString& identifier)
 {
     setName(identifier);
 }
 
-void ClassGenerator::addDeclaration(DeclarationPointer newDeclaration)
+void ClassGenerator::addDeclaration(const DeclarationPointer& newDeclaration)
 {
     m_declarations << newDeclaration;
 }
 
-const QList<DeclarationPointer> ClassGenerator::declarations() const
+QList<DeclarationPointer> ClassGenerator::declarations() const
 {
     return m_declarations;
 }
 
-const QList<DeclarationPointer> & ClassGenerator::addBaseClass(const QString &  newBaseClass)
+QList<DeclarationPointer> ClassGenerator::addBaseClass(const QString&  newBaseClass)
 {
-    DUChainReadLocker lock(DUChain::lock());
-    
+    DUChainReadLocker lock;
+
     bool added = false;
     PersistentSymbolTable::Declarations decl = PersistentSymbolTable::self().getDeclarations(IndexedQualifiedIdentifier(QualifiedIdentifier(newBaseClass)));
-    
+
     //Search for all super classes
     for(PersistentSymbolTable::Declarations::Iterator it = decl.iterator(); it; ++it)
     {
@@ -197,19 +276,19 @@ const QList<DeclarationPointer> & ClassGenerator::addBaseClass(const QString &
             break;
         }
     }
-    
+
     if(!added)
         m_baseClasses << DeclarationPointer(); //Some entities expect that there is always an item added to the list, so just add zero
-    
+
     return m_baseClasses;
 }
 
-const QList<DeclarationPointer> & ClassGenerator::inheritanceList() const
+QList<DeclarationPointer> ClassGenerator::inheritanceList() const
 {
     return d->inheritedClasses;
 }
 
-const QList< DeclarationPointer >& ClassGenerator::directInheritanceList() const
+QList<DeclarationPointer> ClassGenerator::directInheritanceList() const
 {
     return m_baseClasses;
 }
@@ -225,7 +304,7 @@ void ClassGenerator::clearDeclarations()
     m_declarations.clear();
 }
 
-KUrl ClassGenerator::headerUrlFromBase(KUrl baseUrl, bool toLower)
+KUrl ClassGenerator::headerUrlFromBase(const KUrl& baseUrl, bool toLower)
 {
     Q_UNUSED(baseUrl);
     Q_UNUSED(toLower);
@@ -234,30 +313,30 @@ KUrl ClassGenerator::headerUrlFromBase(KUrl baseUrl, bool toLower)
     return url;
 }
 
-KUrl ClassGenerator::implementationUrlFromBase(KUrl baseUrl, bool toLower)
+KUrl ClassGenerator::implementationUrlFromBase(const KUrl& baseUrl, bool toLower)
 {
     Q_UNUSED(baseUrl);
     Q_UNUSED(toLower);
     return KUrl();
 }
 
-void ClassGenerator::setHeaderPosition ( SimpleCursor position )
+void ClassGenerator::setHeaderPosition(const SimpleCursor& position)
 {
     d->headerPosition = position;
 }
 
-void ClassGenerator::setImplementationPosition ( SimpleCursor position )
+void ClassGenerator::setImplementationPosition(const SimpleCursor& position)
 {
     d->implementationPosition = position;
 }
 
-void ClassGenerator::setHeaderUrl ( KUrl header )
+void ClassGenerator::setHeaderUrl(const KUrl& header)
 {
     d->headerUrl = header;
     kDebug() << "Header for the generated class: " << header;
 }
 
-void ClassGenerator::setImplementationUrl ( KUrl implementation )
+void ClassGenerator::setImplementationUrl(const KUrl& implementation)
 {
     d->implementationUrl = implementation;
     kDebug() << "Implementation for the generated class: " << implementation;
@@ -273,51 +352,54 @@ SimpleCursor ClassGenerator::implementationPosition()
     return d->implementationPosition;
 }
 
-KUrl & ClassGenerator::headerUrl()
+KUrl ClassGenerator::headerUrl()
 {
     return d->headerUrl;
 }
 
-KUrl & ClassGenerator::implementationUrl()
+KUrl ClassGenerator::implementationUrl()
 {
     return d->implementationUrl;
 }
 
 /// Specify license for this class
-void ClassGenerator::setLicense(const QString & license)
+void ClassGenerator::setLicense(const QString& license)
 {
     kDebug() << "New Class: " << d->name << "Set license: " << d->license;
     d->license = license;
 }
 
 /// Get the license specified for this classes
-const QString & ClassGenerator::license() const
+QString ClassGenerator::license() const
 {
     return d->license;
 }
 
-void ClassGenerator::fetchSuperClasses(DeclarationPointer derivedClass)
+void ClassGenerator::fetchSuperClasses(const DeclarationPointer& derivedClass)
 {
-    DUChainReadLocker lock(DUChain::lock());
-    
+    DUChainReadLocker lock;
+
     //Prevent duplicity
-    if(d->inheritedClasses.contains(derivedClass))
+    if(d->inheritedClasses.contains(derivedClass)) {
         return;
-    
+    }
+
     d->inheritedClasses.append(derivedClass);
 
     DUContext* context = derivedClass->internalContext();
     if (context) {
-        foreach (const DUContext::Import& import, context->importedParentContexts())
-            if (DUContext * parentContext = import.context(context->topContext()))
-                if (parentContext->type() == DUContext::Class)
+        foreach (const DUContext::Import& import, context->importedParentContexts()) {
+            if (DUContext * parentContext = import.context(context->topContext())) {
+                if (parentContext->type() == DUContext::Class) {
                     fetchSuperClasses( DeclarationPointer(parentContext->owner()) );
+                }
+            }
+        }
     }
 }
 
-class ClassIdentifierPagePrivate
+struct ClassIdentifierPagePrivate
 {
-public:
     ClassIdentifierPagePrivate()
         : classid(0)
     {
@@ -326,28 +408,25 @@ public:
     Ui::NewClassDialog* classid;
 };
 
-ClassIdentifierPage::ClassIdentifierPage(QWizard* parent)
-    : QWizardPage(parent)
-    , d(new ClassIdentifierPagePrivate)
+ClassIdentifierPage::ClassIdentifierPage(QWidget* parent)
+: QWidget(parent)
+, d(new ClassIdentifierPagePrivate())
 {
-    setTitle(i18n("Class Basics"));
-    setSubTitle( i18n("Identify the class and any classes from which it is to inherit.") );
-
     d->classid = new Ui::NewClassDialog;
     d->classid->setupUi(this);
     d->classid->addInheritancePushButton->setIcon(KIcon("list-add"));
     d->classid->removeInheritancePushButton->setIcon(KIcon("list-remove"));
     d->classid->moveDownPushButton->setIcon(KIcon("go-down"));
     d->classid->moveUpPushButton->setIcon(KIcon("go-up"));
-    
+
+    connect(d->classid->identifierLineEdit, SIGNAL(textChanged(QString)), this, SLOT(checkIdentifier()));
     connect(d->classid->addInheritancePushButton, SIGNAL(pressed()), this, SLOT(addInheritance()));
     connect(d->classid->removeInheritancePushButton, SIGNAL(pressed()), this, SLOT(removeInheritance()));
     connect(d->classid->moveUpPushButton, SIGNAL(pressed()), this, SLOT(moveUpInheritance()));
     connect(d->classid->moveDownPushButton, SIGNAL(pressed()), this, SLOT(moveDownInheritance()));
     connect(d->classid->inheritanceList, SIGNAL(currentRowChanged(int)), this, SLOT(checkMoveButtonState()));
 
-    registerField("classIdentifier*", d->classid->identifierLineEdit);
-    registerField("classInheritance", this, "inheritance", SIGNAL(inheritanceChanged()));
+    emit isValid(false);
 }
 
 ClassIdentifierPage::~ClassIdentifierPage()
@@ -365,6 +444,11 @@ KLineEdit* ClassIdentifierPage::inheritanceLineEdit() const
     return d->classid->inheritanceLineEdit;
 }
 
+void ClassIdentifierPage::checkIdentifier()
+{
+    emit isValid(!identifierLineEdit()->userText().isEmpty());
+}
+
 void ClassIdentifierPage::addInheritance()
 {
     d->classid->inheritanceList->addItem(d->classid->inheritanceLineEdit->text());
@@ -373,8 +457,9 @@ void ClassIdentifierPage::addInheritance()
 
     d->classid->removeInheritancePushButton->setEnabled(true);
 
-    if (d->classid->inheritanceList->count() > 1)
+    if (d->classid->inheritanceList->count() > 1) {
         checkMoveButtonState();
+    }
 
     emit inheritanceChanged();
 }
@@ -383,8 +468,9 @@ void ClassIdentifierPage::removeInheritance()
 {
     delete d->classid->inheritanceList->takeItem(d->classid->inheritanceList->currentRow());
 
-    if (d->classid->inheritanceList->count() == 0)
+    if (d->classid->inheritanceList->count() == 0) {
         d->classid->removeInheritancePushButton->setEnabled(false);
+    }
 
     checkMoveButtonState();
 
@@ -396,8 +482,9 @@ void ClassIdentifierPage::moveUpInheritance()
     int currentRow = d->classid->inheritanceList->currentRow();
 
     Q_ASSERT(currentRow > 0);
-    if (currentRow <= 0)
+    if (currentRow <= 0) {
         return;
+    }
 
     QListWidgetItem* item = d->classid->inheritanceList->takeItem(currentRow);
     d->classid->inheritanceList->insertItem(currentRow - 1, item);
@@ -411,8 +498,9 @@ void ClassIdentifierPage::moveDownInheritance()
     int currentRow = d->classid->inheritanceList->currentRow();
 
     Q_ASSERT(currentRow != -1 && currentRow < d->classid->inheritanceList->count() - 1);
-    if (currentRow == -1 || currentRow >= d->classid->inheritanceList->count() - 1)
+    if (currentRow == -1 || currentRow >= d->classid->inheritanceList->count() - 1) {
         return;
+    }
 
     QListWidgetItem* item = d->classid->inheritanceList->takeItem(currentRow);
     d->classid->inheritanceList->insertItem(currentRow + 1, item);
@@ -442,25 +530,8 @@ QStringList ClassIdentifierPage::inheritanceList() const
     return ret;
 }
 
-bool ClassIdentifierPage::validatePage ( void )
+struct LicensePagePrivate
 {
-    //save the information in the generator
-    ClassGenerator * generator = dynamic_cast<CreateClassWizard *>(wizard())->generator();
-    generator->setIdentifier(field("classIdentifier").toString());
-    
-    //Remove old base classes, and add the new ones
-    generator->clearInheritance();
-    foreach (const QString & inherited, field("classInheritance").toStringList())
-        generator->addBaseClass(inherited);
-    
-    return true;
-}
-
-
-class LicensePagePrivate
-{
-public:
-
     struct LicenseInfo
     {
         QString name;
@@ -479,13 +550,10 @@ public:
     LicenseList availableLicenses;
 };
 
-LicensePage::LicensePage(QWizard* parent)
-    : QWizardPage(parent)
-    , d(new LicensePagePrivate)
+LicensePage::LicensePage(QWidget* parent)
+: QWidget(parent)
+, d(new LicensePagePrivate)
 {
-    setTitle(i18n("License"));
-    setSubTitle( i18n("Choose the license under which to place the new class.") );
-
     d->license = new Ui::LicenseChooserDialog;
     d->license->setupUi(this);
 
@@ -494,14 +562,12 @@ LicensePage::LicensePage(QWizard* parent)
 
     // Read all the available licenses from the standard dirs
     initializeLicenses();
-    
+
     //Set the license selection to the previous one
     KConfigGroup config(KGlobal::config()->group("CodeGeneration"));
     d->license->licenseComboBox->setCurrentIndex(config.readEntry( "LastSelectedLicense", 0 ));
     //Needed to avoid a bug where licenseComboChanged doesn't get called by QComboBox if the past selection was 0
     licenseComboChanged(d->license->licenseComboBox->currentIndex());
-
-    registerField("license", d->license->licenseTextEdit);
 }
 
 LicensePage::~LicensePage()
@@ -516,27 +582,32 @@ LicensePage::~LicensePage()
     }
     else
         kWarning() << "Attempted to save an invalid license number: " << index << ". Number of licenses:" << d->availableLicenses.size();
-    
+
     delete d;
 }
 
 // If the user entered a custom license that they want to save, save it
 bool LicensePage::validatePage()
 {
-    if(d->license->licenseComboBox->currentIndex() == (d->availableLicenses.size() - 1) && 
+    if(d->license->licenseComboBox->currentIndex() == (d->availableLicenses.size() - 1) &&
         d->license->saveLicense->isChecked())
         return saveLicense();
     else
         return true;
 }
 
+KTextEdit* LicensePage::licenseTextEdit()
+{
+    return d->license->licenseTextEdit;
+}
+
 //! Read all the license files in the global and local config dirs
 void LicensePage::initializeLicenses()
 {
     kDebug() << "Searching for available licenses";
     KStandardDirs * dirs = KGlobal::dirs();
     QStringList licenseDirs = dirs->findDirs("data", "kdevcodegen/licenses");
-    
+
     //Iterate through the possible directories that contain licenses, and load their names
     foreach(const QString& currentDir, licenseDirs)
     {
@@ -546,14 +617,14 @@ void LicensePage::initializeLicenses()
             LicensePagePrivate::LicenseInfo newLicense;
             newLicense.path = it.next();
             newLicense.name = it.fileName();
-            
+
             kDebug() << "Found License: " << newLicense.name;
-            
+
             d->availableLicenses.push_back(newLicense);
             d->license->licenseComboBox->addItem(newLicense.name);
         }
     }
-    
+
     //Finally add the option other for user specified licenses
     LicensePagePrivate::LicenseInfo license;
     d->availableLicenses.push_back(license);
@@ -561,7 +632,7 @@ void LicensePage::initializeLicenses()
 }
 
 // Read a license index, if it is not loaded, open it from the file
-QString & LicensePage::readLicense(int licenseIndex)
+QString& LicensePage::readLicense(int licenseIndex)
 {
     //If the license is not loaded into memory, read it in
     if(d->availableLicenses[licenseIndex].contents.isEmpty())
@@ -572,7 +643,7 @@ QString & LicensePage::readLicense(int licenseIndex)
         {
             kDebug() << "Reading license: " << d->availableLicenses[licenseIndex].name ;
             QFile newLicense(d->availableLicenses[licenseIndex].path);
-            
+
             if(newLicense.open(QIODevice::ReadOnly | QIODevice::Text))
             {
                 QTextStream newLicenseText(&newLicense);
@@ -624,7 +695,7 @@ void LicensePage::licenseComboChanged(int selectedLicense)
         d->license->saveLicense->setEnabled(false);
         d->license->licenseTextEdit->setReadOnly(true);
     }
-    
+
     if(selectedLicense < 0 || selectedLicense >= d->availableLicenses.size())
         d->license->licenseTextEdit->setText(i18n("Could not load previous license"));
     else
@@ -634,20 +705,20 @@ void LicensePage::licenseComboChanged(int selectedLicense)
 bool LicensePage::saveLicense()
 {
     kDebug() << "Attempting to save custom license: " << d->license->licenseName->text();
-    
+
     QString localDataDir = KStandardDirs::locateLocal("data", "kdevcodegen/licenses/", KGlobal::activeComponent());
     QFile newFile(localDataDir + d->license->licenseName->text());
-    
+
     if(newFile.exists())
     {
         KMessageBox::sorry(this, i18n("The specified license already exists. Please provide a different name."));
         return false;
     }
-    
+
     newFile.open(QIODevice::WriteOnly);
     qint64 result = newFile.write(d->license->licenseTextEdit->toPlainText().toUtf8());
     newFile.close();
-    
+
     if(result == -1)
     {
         KMessageBox::sorry(this, i18n("There was an error writing the file."));
@@ -657,17 +728,16 @@ bool LicensePage::saveLicense()
     return true;
 }
 
-class OutputPagePrivate
+struct OutputPagePrivate
 {
-public:
     OutputPagePrivate()
         : output(0)
     {
     }
 
     Ui::OutputLocationDialog* output;
-    CreateClassWizard* parent;
-    
+    CreateClassAssistant* parent;
+
     void updateRanges(KIntNumInput * line, KIntNumInput * column, bool enable);
 };
 
@@ -678,13 +748,11 @@ void OutputPagePrivate::updateRanges(KIntNumInput * line, KIntNumInput * column,
     column->setEnabled(enable);
 }
 
-OutputPage::OutputPage(CreateClassWizard* parent)
-    : QWizardPage(parent)
-    , d(new OutputPagePrivate)
+OutputPage::OutputPage(CreateClassAssistant* parent)
+: QWidget(parent)
+, d(new OutputPagePrivate)
 {
     d->parent = parent;
-    setTitle(i18n("Output"));
-    setSubTitle( i18n("Choose where to save the new class.") );
 
     d->output = new Ui::OutputLocationDialog;
     d->output->setupUi(this);
@@ -692,14 +760,11 @@ OutputPage::OutputPage(CreateClassWizard* parent)
     d->output->headerUrl->fileDialog()->setOperationMode( KFileDialog::Saving );
     d->output->implementationUrl->setMode( KFile::File | KFile::LocalOnly );
     d->output->implementationUrl->fileDialog()->setOperationMode( KFileDialog::Saving );
-    
-    
+
+
     connect(d->output->lowerFilenameCheckBox, SIGNAL(stateChanged(int)), this, SLOT(updateFileNames()));
     connect(d->output->headerUrl, SIGNAL(textChanged(QString)), this, SLOT(updateHeaderRanges(QString)));
     connect(d->output->implementationUrl, SIGNAL(textChanged(QString)), this, SLOT(updateImplementationRanges(QString)));
-    
-    registerField("headerUrl", d->output->headerUrl);
-    registerField("implementationUrl", d->output->implementationUrl);
 }
 
 void OutputPage::initializePage()
@@ -711,7 +776,6 @@ void OutputPage::initializePage()
     d->output->lowerFilenameCheckBox->setChecked(lower);
 
     updateFileNames();
-    QWizardPage::initializePage();
 }
 
 void OutputPage::updateFileNames() {
@@ -722,18 +786,24 @@ void OutputPage::updateFileNames() {
     KSharedConfigPtr config = KGlobal::config();
     KConfigGroup codegenGroup( config, "CodeGeneration" );
     codegenGroup.writeEntry( "LowerCaseFilenames", d->output->lowerFilenameCheckBox->isChecked() );
+
+    emit isValid(isComplete());
 }
 
-void OutputPage::updateHeaderRanges(const QString & url)
+void OutputPage::updateHeaderRanges(const QString& url)
 {
     QFileInfo info(url);
     d->updateRanges(d->output->headerLineNumber, d->output->headerColumnNumber, info.exists() && !info.isDir());
+
+    emit isValid(isComplete());
 }
 
-void OutputPage::updateImplementationRanges(const QString & url)
+void OutputPage::updateImplementationRanges(const QString& url)
 {
     QFileInfo info(url);
     d->updateRanges(d->output->implementationLineNumber, d->output->implementationColumnNumber, info.exists() && !info.isDir());
+
+    emit isValid(isComplete());
 }
 
 bool OutputPage::isComplete() const
@@ -757,4 +827,6 @@ OutputPage::~OutputPage()
 
 }
 
+Q_DECLARE_TYPEINFO(KDevelop::LicensePagePrivate::LicenseInfo, Q_MOVABLE_TYPE);
+
 #include "createclass.moc"
