@@ -374,6 +374,9 @@ KDEVPLATFORMLANGUAGE_EXPORT uint qHash(const Identifier& id);
 
 }
 
+Q_DECLARE_TYPEINFO(KDevelop::IndexedQualifiedIdentifier, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(KDevelop::IndexedIdentifier, Q_MOVABLE_TYPE);
+
 #endif // IDENTIFIER_H
 
 // kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
