@@ -73,9 +73,8 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
   }
   
   if( m_previousContext ) {
-    modifyHtml() += navigationHighlight("Back to ");
-    makeLink( m_previousContext->name(), m_previousContext->name(), NavigationAction(m_previousContext) );
-    modifyHtml() += "<br>";
+    QString link = createLink( m_previousContext->name(), m_previousContext->name(), NavigationAction(m_previousContext) );
+    modifyHtml() += navigationHighlight(i18n("Back to %1<br />", link));
   }
   
   KSharedPtr<IDocumentation> doc;
@@ -98,7 +97,7 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
         //Do not show the own name as type of typedefs
         if(useType.cast<TypeAliasType>())
           useType = useType.cast<TypeAliasType>()->type();
-      }
+      } 
       
       eventuallyMakeTypeLinks( useType );
 
@@ -236,20 +235,20 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
     else
       modifyHtml() += labelHighlight(i18n( "Decl.: " ));
 
-    makeLink( QString("%1 :%2").arg( KUrl(m_declaration->url().str()).fileName() ).arg( m_declaration->range().textRange().start().line()+1 ), m_declaration, NavigationAction::JumpToSource );
+    makeLink( QString("%1 :%2").arg( KUrl(m_declaration->url().str()).fileName() ).arg( m_declaration->rangeInCurrentRevision().textRange().start().line()+1 ), m_declaration, NavigationAction::JumpToSource );
     modifyHtml() += " ";
     //modifyHtml() += "<br />";
     if(!dynamic_cast<FunctionDefinition*>(m_declaration.data())) {
       if( FunctionDefinition* definition = FunctionDefinition::definition(m_declaration.data()) ) {
         modifyHtml() += labelHighlight(i18n( " Def.: " ));
-        makeLink( QString("%1 :%2").arg( KUrl(definition->url().str()).fileName() ).arg( definition->range().textRange().start().line()+1 ), DeclarationPointer(definition), NavigationAction::JumpToSource );
+        makeLink( QString("%1 :%2").arg( KUrl(definition->url().str()).fileName() ).arg( definition->rangeInCurrentRevision().textRange().start().line()+1 ), DeclarationPointer(definition), NavigationAction::JumpToSource );
       }
     }
 
     if( FunctionDefinition* definition = dynamic_cast<FunctionDefinition*>(m_declaration.data()) ) {
       if(definition->declaration()) {
         modifyHtml() += labelHighlight(i18n( " Decl.: " ));
-        makeLink( QString("%1 :%2").arg( KUrl(definition->declaration()->url().str()).fileName() ).arg( definition->declaration()->range().textRange().start().line()+1 ), DeclarationPointer(definition->declaration()), NavigationAction::JumpToSource );
+        makeLink( QString("%1 :%2").arg( KUrl(definition->declaration()->url().str()).fileName() ).arg( definition->declaration()->rangeInCurrentRevision().textRange().start().line()+1 ), DeclarationPointer(definition->declaration()), NavigationAction::JumpToSource );
       }
     }
     
@@ -263,7 +262,7 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
     if(comment.isEmpty() && doc) {
       comment = doc->description();
       if(!comment.isEmpty()) {
-        modifyHtml() += commentHighlight(comment) /*+ "<br />"*/;
+        modifyHtml() += "<br />" + commentHighlight(comment);
       }
     } else if(!comment.isEmpty()) {
       comment.replace("<br />", "\n"); //do not escape html newlines within the comment
@@ -388,7 +387,7 @@ void AbstractDeclarationNavigationContext::htmlAdditionalNavigation()
       foreach(const DUContext::Import &import, m_declaration->context()->importedParentContexts())
         if(import.context(m_topContext.data()))
           decls += import.context(m_topContext.data())->findDeclarations(QualifiedIdentifier(m_declaration->identifier()), 
-                                                SimpleCursor::invalid(), AbstractType::Ptr(), m_topContext.data(), DUContext::DontSearchInParent);
+                                                CursorInRevision::invalid(), AbstractType::Ptr(), m_topContext.data(), DUContext::DontSearchInParent);
       uint num = 0;
       foreach(Declaration* decl, decls) {
         modifyHtml() += i18n("Hides a ");
@@ -645,15 +644,17 @@ QStringList AbstractDeclarationNavigationContext::declarationDetails(Declaration
   }
 
   if( decl->isDefinition() )
-    details << "definition";
+    details << i18nc("tells if a declaration is defining the variable's value", "definition");
+  if( decl->isExplicitlyDeleted() )
+    details << "deleted";
 
   if( memberDecl && memberDecl->isForwardDeclaration() )
-    details << "forward";
+    details << i18nc("as in c++ forward declaration", "forward");
 
   AbstractType::Ptr t(decl->abstractType());
   if( t ) {
     if( t->modifiers() & AbstractType::ConstModifier )
-      details << "constant";
+      details << i18nc("a variable that won't change, const", "constant");
     if( t->modifiers() & AbstractType::VolatileModifier )
       details << "volatile";
   }
