@@ -37,9 +37,11 @@ private slots:
     void testStringSets();
     void testSymbolTableValid();
     void testIndexedStrings();
+    void testImportStructure();
     ///NOTE: these are not "automated"!
-//     void testImportStructure();
 //     void testImportCache();
+
+    void benchCodeModel();
 };
 
-#endif // TEST_DUCHAIN_H
\ No newline at end of file
+#endif // TEST_DUCHAIN_H
