@@ -92,45 +92,9 @@ ReferencedTopDUContext& ReferencedTopDUContext::operator=(const ReferencedTopDUC
   return *this;
 }
 
-IndexedTopDUContext::IndexedTopDUContext(TopDUContext* context) {
-  if(context)
-    m_index = context->ownIndex();
-  else
-    m_index = DummyMask;
-}
-
-bool IndexedTopDUContext::isLoaded() const {
-  if(index())
-    return DUChain::self()->isInMemory(index());
-  else
-    return false;
-}
-
-IndexedString IndexedTopDUContext::url() const {
-  if(index())
-    return DUChain::self()->urlForIndex(index());
-  else
-    return IndexedString();
-}
-
-TopDUContext* IndexedTopDUContext::data() const {
-//   ENSURE_CHAIN_READ_LOCKED
-  if(index())
-    return DUChain::self()->chainForIndex(index());
-  else
-    return 0;
-}
-
 DEFINE_LIST_MEMBER_HASH(TopDUContextData, m_usedDeclarationIds, DeclarationId)
 REGISTER_DUCHAIN_ITEM(TopDUContext);
 
-class TopDUContext::CacheData {
-  public:
-    CacheData(TopDUContextPointer _context) : context(_context) {
-    }
-    TopDUContextPointer context;
-};
-
 template <class T>
 void removeFromVector(QVector<T>& vec, const T& t) {
   for(int a  =0; a < vec.size(); ++a) {
@@ -162,16 +126,6 @@ public:
     }
   }
 
-  mutable QHash<QThread*, TopDUContext::CacheData*> m_threadCaches;
-
-  TopDUContext::CacheData* currentCache() const {
-    QHash<QThread*, TopDUContext::CacheData*>::iterator it = m_threadCaches.find(QThread::currentThread());
-    if(it != m_threadCaches.end())
-      return *it;
-    else
-      return 0;
-  }
-
   ~TopDUContextLocalPrivate() {
     //Either we use some other contexts data and have no users, or we own the data and have users that share it.
     QMutexLocker lock(&importStructureMutex);
@@ -554,39 +508,6 @@ bool TopDUContext::DeclarationChecker::operator()(const Declaration* decl) const
   return true;
 }
 
-// ImportTrace TopDUContext::importTrace(const TopDUContext* target) const
-// {
-//   ImportTrace ret;
-//   importTrace(target, ret);
-//   return ret;
-// }
-//
-// void TopDUContext::importTrace(const TopDUContext* target, ImportTrace& store) const
-// {
-//     QMutexLocker lock(&importStructureMutex);
-//
-//     const TopDUContext* current = this;
-//     while(current != target) {
-// //       current->d_func()->needImportStructure();
-//
-//       TopDUContextLocalPrivate::RecursiveImports::const_iterator it = current->m_local->m_recursiveImports.constFind(target);
-//
-//       if(it == current->m_local->m_recursiveImports.constEnd())
-//         return;
-//
-//       const TopDUContext* nextContext = (*it).second;
-//
-//       if(nextContext) {
-//         store.append(ImportTraceItem(current, current->importPosition(nextContext)));
-//
-//         current = nextContext;
-//       }else{
-//         kWarning() << "inconsistent import-structure";
-//         return;
-//       }
-//   }
-// }
-
 const TopDUContext::IndexedRecursiveImports& TopDUContext::recursiveImportIndices() const
 {
 //   No lock-check for performance reasons
@@ -865,7 +786,6 @@ void TopDUContext::setParsingEnvironmentFile(ParsingEnvironmentFile* file)
 
 struct TopDUContext::FindDeclarationsAcceptor {
   FindDeclarationsAcceptor(const TopDUContext* _top, DeclarationList& _target, const DeclarationChecker& _check, SearchFlags _flags) : top(_top), target(_target), check(_check) {
-    cache = _top->m_local->currentCache();
     flags = _flags;
   }
 
@@ -926,7 +846,6 @@ struct TopDUContext::FindDeclarationsAcceptor {
   }
 
   const TopDUContext* top;
-  CacheData* cache;
   DeclarationList& target;
   const DeclarationChecker& check;
   QFlags< KDevelop::DUContext::SearchFlag > flags;
@@ -1174,6 +1093,12 @@ void TopDUContext::addProblem(const ProblemPointer& problem)
   m_local->m_problems << problem;
 }
 
+void TopDUContext::removeProblem(const ProblemPointer& problem)
+{
+  ENSURE_CAN_WRITE
+  m_local->m_problems.removeOne(problem);
+}
+
 void TopDUContext::clearProblems()
 {
   ENSURE_CAN_WRITE
@@ -1381,21 +1306,6 @@ QList<RangeInRevision> allUses(TopDUContext* context, Declaration* declaration,
   return allUses(context, declarationIndex, noEmptyRanges);
 }
 
-///@todo move this kind of caching into the symbol-table
-TopDUContext::Cache::Cache(TopDUContextPointer context) : d(new CacheData(context)) {
-  DUChainWriteLocker lock(DUChain::lock());
-  if(d->context)
-    d->context->m_local->m_threadCaches.insert(QThread::currentThread(), d);
-}
-
-TopDUContext::Cache::~Cache() {
-  DUChainWriteLocker lock(DUChain::lock());
-  if(d->context && d->context->m_local->m_threadCaches[QThread::currentThread()] == d)
-    d->context->m_local->m_threadCaches.remove(QThread::currentThread());
-
-  delete d;
-}
-
 KSharedPtr<IAstContainer> TopDUContext::ast() const
 {
   return m_local->m_ast;
