@@ -24,7 +24,7 @@
 
 #include "ducontext.h"
 #include <language/util/setrepository.h>
-#include "indexeditems.h"
+#include <QMetaType>
 
 template< class T >
 class KSharedPtr;
@@ -171,6 +171,11 @@ public:
    * */
   void addProblem(const ProblemPointer& problem);
 
+  /**
+   * Remove a parsing-problem from this context.
+   * */
+  void removeProblem(const ProblemPointer& problem);
+
   /// Clear the list of problems
   void clearProblems();
 
@@ -184,16 +189,6 @@ public:
    */
   virtual bool imports(const DUContext* origin, const CursorInRevision& position) const;
 
-  /**
-   * Returns the trace of imports from this context top the given target.
-   * The positions in the returned trace may be invalid.
-   * This is more efficient then the version below, because the trace doesn't need to be copied
-   * */
-//   void importTrace(const TopDUContext* target, ImportTrace& store) const;
-
-  ///More convenient version of the above
-//   ImportTrace importTrace(const TopDUContext* target) const;
-
   enum {
     Identity = 4
   };
@@ -319,24 +314,6 @@ public:
   
   virtual CursorInRevision importPosition(const DUContext* target) const;
   
-  class CacheData;
-
-  /**The cache allows speeding up repeated searches. When you're planning to do many searches from within the same top-context,
-    *this should be done. Just create an item of type Cache, and give it the du-context. The duchain must not be locked when calling this.
-    *The cache will automatically be discarded on destruction of the item. It is thread-local, so you don't need to care about multi-threading.
-    *@warning The DUChain must not be locked when the constructor is called, and it must not be locked when the destructor is executed.
-    *@warning Only use this in phases when you're not changing the Data within this contexts, else the cache will become invalid and search will be fuzzy.
-    */
-  class KDEVPLATFORMLANGUAGE_EXPORT Cache {
-    public:
-    Cache(TopDUContextPointer context);
-    ~Cache();
-
-    private:
-    Q_DISABLE_COPY(Cache)
-    CacheData* d;
-  };
-  
   ///Returns the set of all recursively imported top-contexts. If import-caching is used, this returns the cached set.
   ///The list also contains this context itself. This set is used to determine declaration-visibility from within this top-context.
   const IndexedRecursiveImports& recursiveImportIndices() const;
@@ -424,6 +401,7 @@ inline uint qHash(const IndexedTopDUContext& ctx) {
 }
 
 }
+Q_DECLARE_METATYPE(KDevelop::ReferencedTopDUContext);
 
 #endif // TOPDUCONTEXT_H
 
