@@ -622,6 +622,11 @@ void GitPlugin::parseGitBranchOutput(DVcsJob* job)
     QStringList branchList;
     foreach(QString branch, branchListDirty)
     {
+        // Skip pointers to another branches (one example of this is "origin/HEAD -> origin/master");
+        // "git rev-list" chokes on these entries and we do not need duplicate branches altogether.
+        if (branch.contains("->"))
+            continue;
+        
         if (branch.startsWith('*'))
             branch = branch.right(branch.size()-2);
         
@@ -826,6 +831,7 @@ void GitPlugin::initBranchHash(const QString &repo)
     QScopedPointer<DVcsJob> job(gitRevList(repo, QStringList(root)));
     bool ret = job->exec();
     Q_ASSERT(ret && job->status()==VcsJob::JobSucceeded && "TODO: provide a fall back in case of failing");
+    Q_UNUSED(ret);
     QStringList commits = job->output().split('\n', QString::SkipEmptyParts);
 //     kDebug() << "\n\n\n commits" << commits << "\n\n\n";
     branchesShas.append(commits);
