@@ -41,7 +41,9 @@
 #include <interfaces/iruncontroller.h>
 #include <interfaces/idocumentcontroller.h>
 #include <kparts/mainwindow.h>
-
+#include <KMessageBox>
+#include <QApplication>
+#include <KConfigGroup>
 using namespace KDevelop;
 
 K_PLUGIN_FACTORY(KDevOpenWithFactory, registerPlugin<OpenWithPlugin>(); )
@@ -50,9 +52,10 @@ K_EXPORT_PLUGIN(KDevOpenWithFactory(KAboutData("kdevopenwith","kdevopenwith", ki
 
 OpenWithPlugin::OpenWithPlugin ( QObject* parent, const QVariantList& ) 
     : IPlugin ( KDevOpenWithFactory::componentData(), parent ),
-    actionMap( 0 )
+    m_actionMap( 0 )
 {
-    setXMLFile( "kdevopenwithui.rc" );
+//    setXMLFile( "kdevopenwithui.rc" );
+    KDEV_USE_EXTENSION_INTERFACE( IOpenWith )
 }
 
 OpenWithPlugin::~OpenWithPlugin()
@@ -61,55 +64,59 @@ OpenWithPlugin::~OpenWithPlugin()
 
 KDevelop::ContextMenuExtension OpenWithPlugin::contextMenuExtension ( KDevelop::Context* context )
 {
-    if( actionMap )
+    if( m_actionMap )
     {
-        delete actionMap;
-        actionMap = 0;
+        delete m_actionMap;
+        m_actionMap = 0;
     }
-    urls = QList<KUrl>();
+    m_urls = QList<KUrl>();
     FileContext* filectx = dynamic_cast<FileContext*>( context );
     ProjectItemContext* projctx = dynamic_cast<ProjectItemContext*>( context );
     if( filectx && filectx->urls().count() > 0 )
     {
-        urls = filectx->urls();
+        m_urls = filectx->urls();
     } else if ( projctx && projctx->items().count() > 0 )
     {
         foreach( ProjectBaseItem* item, projctx->items() )
         {
             if( item->file() )
             {
-                urls << item->file()->url();
+                m_urls << item->file()->url();
             }
         }
     }
-    if( !urls.isEmpty() )
+    if( !m_urls.isEmpty() )
     {
-        actionMap = new QSignalMapper( this );
-        connect( actionMap, SIGNAL(mapped(const QString&)), SLOT(open(const QString&)) );
-        
+        m_actionMap = new QSignalMapper( this );
+        connect( m_actionMap, SIGNAL(mapped(QString)), SLOT(open(QString)) );
+
         // Ok, lets fetch the mimetype for the !!first!! url and the relevant services
         // TODO: Think about possible alternatives to using the mimetype of the first url.
-        KMimeType::Ptr mimetype = KMimeType::findByUrl( urls.first() );
-        KService::List apps = KMimeTypeTrader::self()->query( mimetype->name() );
-        KService::Ptr preferredapp = KMimeTypeTrader::self()->preferredService( mimetype->name() );
-        KService::List parts = KMimeTypeTrader::self()->query( mimetype->name(), "KParts/ReadOnlyPart" );
-        KService::Ptr preferredpart = KMimeTypeTrader::self()->preferredService( mimetype->name(), "KParts/ReadOnlyPart" );
-        
-        // Now setup a menu with actions for each part and app
-        KMenu* menu = new KMenu( i18n("Open With" ) );
-        menu->setIcon( SmallIcon( "document-open" ) );
-        
-        menu->addActions( actionsForServices( parts, preferredpart ) );
-        menu->addActions( actionsForServices( apps, preferredapp ) );
-        
-        KAction* openAction = new KAction( i18n( "Open" ), this );
-        openAction->setIcon( SmallIcon( "document-open" ) );
-        connect( openAction, SIGNAL( triggered() ), SLOT( openDefault() ) );
+        KMimeType::Ptr mimetype = KMimeType::findByUrl( m_urls.first() );
+        if(!mimetype->is("inode/directory")){
+            m_mimeType = mimetype->name();
+            KService::List apps = KMimeTypeTrader::self()->query( m_mimeType );
+            KService::Ptr preferredapp = KMimeTypeTrader::self()->preferredService( m_mimeType );
+            KService::List parts = KMimeTypeTrader::self()->query( m_mimeType, "KParts/ReadOnlyPart" );
+            KService::Ptr preferredpart = KMimeTypeTrader::self()->preferredService( m_mimeType,
+                                                                                     "KParts/ReadOnlyPart" );
 
-        KDevelop::ContextMenuExtension ext;
-        ext.addAction( KDevelop::ContextMenuExtension::FileGroup, openAction );
-        ext.addAction( KDevelop::ContextMenuExtension::FileGroup, menu->menuAction() );
-        return ext;
+            // Now setup a menu with actions for each part and app
+            KMenu* menu = new KMenu( i18n("Open With" ) );
+            menu->setIcon( SmallIcon( "document-open" ) );
+
+            menu->addActions( actionsForServices( parts, preferredpart ) );
+            menu->addActions( actionsForServices( apps, preferredapp ) );
+
+            KAction* openAction = new KAction( i18n( "Open" ), this );
+            openAction->setIcon( SmallIcon( "document-open" ) );
+            connect( openAction, SIGNAL(triggered()), SLOT(openDefault()) );
+
+            KDevelop::ContextMenuExtension ext;
+            ext.addAction( KDevelop::ContextMenuExtension::FileGroup, openAction );
+            ext.addAction( KDevelop::ContextMenuExtension::FileGroup, menu->menuAction() );
+            return ext;
+        }
     }
     return KDevelop::IPlugin::contextMenuExtension ( context );
 }
@@ -122,8 +129,8 @@ QList< QAction* > OpenWithPlugin::actionsForServices ( const KService::List& lis
     {
         KAction* act = new KAction( svc->name(), this );
         act->setIcon( SmallIcon( svc->icon() ) );
-        connect(act, SIGNAL(triggered()), actionMap, SLOT(map()));
-        actionMap->setMapping( act, svc->storageId() );
+        connect(act, SIGNAL(triggered()), m_actionMap, SLOT(map()));
+        m_actionMap->setMapping( act, svc->storageId() );
         if( svc->storageId() == pref->storageId() )
         {
             openactions.prepend( act );
@@ -137,7 +144,15 @@ QList< QAction* > OpenWithPlugin::actionsForServices ( const KService::List& lis
 
 void OpenWithPlugin::openDefault()
 {
-    foreach( const KUrl& u, urls ) {
+    KConfigGroup config = KGlobal::config()->group("Open With Defaults");
+    if (config.hasKey(m_mimeType)) {
+        QString storageId = config.readEntry(m_mimeType, QString());
+        if (!storageId.isEmpty() && KService::serviceByStorageId(storageId)) {
+            open(storageId);
+            return;
+        }
+    }
+    foreach( const KUrl& u, m_urls ) {
         ICore::self()->documentController()->openDocument( u );
     }
 }
@@ -147,7 +162,7 @@ void OpenWithPlugin::open ( const QString& storageid )
     KService::Ptr svc = KService::serviceByStorageId( storageid );
     if( svc->isApplication() )
     {
-        KRun::run( *svc, urls, ICore::self()->uiController()->activeMainWindow() );
+        KRun::run( *svc, m_urls, ICore::self()->uiController()->activeMainWindow() );
     } else 
     {
         QString prefName = svc->desktopEntryName();
@@ -158,9 +173,35 @@ void OpenWithPlugin::open ( const QString& storageid )
             // TODO: Solve this rather inside DocumentController
             prefName = "";
         }
-        foreach( const KUrl& u, urls )
+        foreach( const KUrl& u, m_urls )
         {
             ICore::self()->documentController()->openDocument( u, prefName );
         }
     }
+
+    KConfigGroup config = KGlobal::config()->group("Open With Defaults");
+    if (storageid != config.readEntry(m_mimeType, QString())) {
+        int setDefault = KMessageBox::questionYesNo(
+            qApp->activeWindow(),
+            i18n("Do you want to open %1 files by default with %2?",
+                 m_mimeType, svc->name() ),
+            i18n("Set as default?"),
+            KStandardGuiItem::yes(), KStandardGuiItem::no(),
+            QString("OpenWith-%1").arg(m_mimeType)
+        );
+        if (setDefault == KMessageBox::Yes) {
+            config.writeEntry(m_mimeType, storageid);
+        }
+    }
+}
+
+void OpenWithPlugin::openFilesInternal( const KUrl::List& files )
+{
+    if (files.isEmpty()) {
+        return;
+    }
+
+    m_urls = files;
+    m_mimeType = KMimeType::findByUrl( m_urls.first() )->name();
+    openDefault();
 }
