@@ -93,7 +93,10 @@ class QuickOpenWidgetCreator {
 
 class StandardQuickOpenWidgetCreator : public QuickOpenWidgetCreator {
   public:
-    StandardQuickOpenWidgetCreator(QStringList items, QStringList scopes) : m_items(items), m_scopes(scopes) {
+    StandardQuickOpenWidgetCreator(const QStringList& items, const QStringList& scopes)
+      : m_items(items)
+      , m_scopes(scopes)
+    {
     }
 
     virtual QString objectNameForLine() {
@@ -273,7 +276,6 @@ void QuickOpenWidget::showStandardButtons(bool show)
 
 QuickOpenWidget::QuickOpenWidget( QString title, QuickOpenModel* model, const QStringList& initialItems, const QStringList& initialScopes, bool listOnly, bool noSearchField ) : m_model(model), m_expandedTemporary(false) {
   m_filterTimer.setSingleShot(true);
-  m_filterTimer.setInterval(150);
   connect(&m_filterTimer, SIGNAL(timeout()), this, SLOT(applyFilter()));
 
   Q_UNUSED( title );
@@ -347,10 +349,28 @@ QuickOpenWidget::QuickOpenWidget( QString title, QuickOpenModel* model, const QS
   connect(o.cancelButton, SIGNAL(clicked(bool)), SIGNAL(ready()));
   
   updateProviders();
+  updateTimerInterval(true);
+  
 // no need to call this, it's done by updateProviders already
 //   m_model->restart();
 }
 
+void QuickOpenWidget::updateTimerInterval(bool cheapFilterChange)
+{
+  const int MAX_ITEMS = 10000;
+  if ( cheapFilterChange && m_model->rowCount(QModelIndex()) < MAX_ITEMS ) {
+    // cheap change and there are currently just a few items,
+    // so apply filter instantly
+    m_filterTimer.setInterval(0);
+  } else if ( m_model->unfilteredRowCount() < MAX_ITEMS ) {
+    // not a cheap change, but there are generally
+    // just a few items in the list: apply filter instantly
+    m_filterTimer.setInterval(0);
+  } else {
+    // otherwise use a timer to prevent sluggishness while typing
+    m_filterTimer.setInterval(300);
+  }
+}
 
 void QuickOpenWidget::showEvent(QShowEvent* e)
 {
@@ -495,6 +515,8 @@ void QuickOpenWidget::updateScrollBarState()
 
 void QuickOpenWidget::textChanged( const QString& str )
 {
+  // "cheap" when something was just appended to the current filter
+  updateTimerInterval(str.startsWith(m_filter));
   m_filter = str;
   m_filterTimer.start();
 }
@@ -533,14 +555,12 @@ void QuickOpenWidget::accept() {
 }
 
 void QuickOpenWidget::doubleClicked ( const QModelIndex & index ) {
-  QString filterText = o.searchLine->text();
-  if(  m_model->execute( index, filterText ) )
-    emit ready();
-  else if( filterText != o.searchLine->text() )
-    o.searchLine->setText( filterText );
+  // crash guard: https://bugs.kde.org/show_bug.cgi?id=297178
+  o.list->setCurrentIndex(index);
+  QMetaObject::invokeMethod(this, "accept", Qt::QueuedConnection);
+  QMetaObject::invokeMethod(this, "ready", Qt::QueuedConnection);
 }
 
-
 bool QuickOpenWidget::eventFilter ( QObject * watched, QEvent * event )
 {
   QKeyEvent *keyEvent = dynamic_cast<QKeyEvent*>(event);
@@ -665,6 +685,10 @@ bool QuickOpenWidget::eventFilter ( QObject * watched, QEvent * event )
       }
       case Qt::Key_Return:
       case Qt::Key_Enter: {
+        if (m_filterTimer.isActive()) {
+          m_filterTimer.stop();
+          applyFilter();
+        }
         if( keyEvent->modifiers() == Qt::AltModifier ) {
           //Eventually Send action to the widget
           QWidget* w = m_model->expandingWidget(o.list->selectionModel()->currentIndex());
