@@ -119,8 +119,8 @@ OutputWidget::OutputWidget(QWidget* parent, ToolViewData* tvdata)
         filterInput = new KLineEdit();
         filterInput->setMaximumWidth(150);
         filterInput->setMinimumWidth(100);
-        filterInput->setClickMessage("search...");
-        filterInput->setToolTip("Enter a wild card string to filter the output view");
+        filterInput->setClickMessage(i18n("Search..."));
+        filterInput->setToolTip(i18n("Enter a wild card string to filter the output view"));
         filterAction = new QWidgetAction(this);
         filterAction->setDefaultWidget(filterInput);
         addAction(filterAction);
@@ -524,7 +524,7 @@ void OutputWidget::copySelection()
     QModelIndexList indexes = view->selectionModel()->selectedRows();
     QString content;
     Q_FOREACH( QModelIndex index, indexes) {
-      content += view->model()->data(index).toString() + "\n";
+      content += view->model()->data(index).toString() + '\n';
     }
     cb->setText(content);
 }
