@@ -55,7 +55,12 @@ ProjectSourcePage::ProjectSourcePage(const KUrl& initial, QWidget* parent)
     connect(m_ui->sources, SIGNAL(currentIndexChanged(int)), SLOT(sourceChanged(int)));
     connect(m_ui->get, SIGNAL(clicked()), SLOT(getVcsProject()));
     
+    emit isCorrect(false);
+
     sourceChanged(0);
+    
+    if(!m_plugins.isEmpty())
+        m_ui->sources->setCurrentIndex(1);
 }
 
 void ProjectSourcePage::sourceChanged(int index)
@@ -82,6 +87,7 @@ void ProjectSourcePage::sourceChanged(int index)
         if(providerIface) {
             found=true;
             m_providerWidget=providerIface->providerWidget(m_ui->sourceBox);
+            connect(m_providerWidget, SIGNAL(changed(QString)), SLOT(projectChanged(QString)));
             
             remoteWidgetLayout->addWidget(m_providerWidget);   
         }
@@ -127,7 +133,6 @@ VcsJob* ProjectSourcePage::jobPerCurrent()
 
 void ProjectSourcePage::getVcsProject()
 {
-    emit isCorrect(false);
     KUrl url=m_ui->workingDir->url();
     QDir d(url.toLocalFile());
     if(!url.isLocalFile() && !d.exists()) {
@@ -140,9 +145,13 @@ void ProjectSourcePage::getVcsProject()
     
     VcsJob* job=jobPerCurrent();
     
+    m_ui->sources->setEnabled(false);
+    m_ui->sourceBox->setEnabled(false);
+    m_ui->workingDir->setEnabled(false);
+    m_ui->get->setEnabled(false);
     m_ui->creationProgress->setValue(m_ui->creationProgress->minimum());
     connect(job, SIGNAL(result(KJob*)), SLOT(projectReceived(KJob*)));
-    connect(job, SIGNAL(percent(KJob*, unsigned long)), SLOT(progressChanged(KJob*, unsigned long)));
+    connect(job, SIGNAL(percent(KJob*,ulong)), SLOT(progressChanged(KJob*,ulong)));
     connect(job, SIGNAL(infoMessage(KJob*,QString,QString)), SLOT(infoMessage(KJob*,QString,QString)));
     ICore::self()->runController()->registerJob(job);
 }
@@ -152,13 +161,13 @@ void ProjectSourcePage::progressChanged(KJob*, unsigned long value)
     m_ui->creationProgress->setValue(value);
 }
 
-void ProjectSourcePage::infoMessage(KJob* , const QString& text, const QString& rich)
+void ProjectSourcePage::infoMessage(KJob* , const QString& text, const QString& /*rich*/)
 {
     m_ui->creationProgress->setFormat(i18nc("Format of the progress bar text. progress and info",
                                             "%1 : %p%", text));
 }
 
-void ProjectSourcePage::projectReceived(KJob* job)
+void ProjectSourcePage::projectReceived(KJob* /*job*/)
 {
     m_ui->creationProgress->setValue(m_ui->creationProgress->maximum());
     
@@ -171,8 +180,8 @@ void ProjectSourcePage::reevaluateCorrection()
     //TODO: Probably we should just ignore remote URL's, I don't think we're ever going
     //to support checking out to remote directories
     KUrl cwd=m_ui->workingDir->url();
-    bool correct=!cwd.isEmpty() && (!cwd.isLocalFile() || QDir(cwd.upUrl().toLocalFile()).exists());
-    emit isCorrect(correct);
+    bool correct=!cwd.isRelative() && (!cwd.isLocalFile() || QDir(cwd.upUrl().toLocalFile()).exists());
+    emit isCorrect(correct && m_ui->creationProgress->value() == m_ui->creationProgress->maximum());
     
     QDir d(cwd.toLocalFile());
     bool validToCheckout=correct && (!m_locationWidget || m_locationWidget->isCorrect()); //To checkout, if it exists, it should be an empty dir
@@ -185,7 +194,7 @@ void ProjectSourcePage::reevaluateCorrection()
     
     if(!correct)
         setStatus(i18n("You need to specify a valid or nonexistent directory to check out a project"));
-    else if(!m_ui->get->isEnabled())
+    else if(!m_ui->get->isEnabled() && m_ui->workingDir->isEnabled())
         setStatus(i18n("You need to specify a valid location for the project"));
     else
         validStatus();
@@ -207,6 +216,18 @@ void ProjectSourcePage::locationChanged()
         reevaluateCorrection();
 }
 
+void ProjectSourcePage::projectChanged(const QString& name)
+{
+    Q_ASSERT(m_providerWidget);
+    QString currentUrl = m_ui->workingDir->text();
+    currentUrl = currentUrl.left(currentUrl.lastIndexOf('/')+1);
+    
+    KUrl current = currentUrl;
+    current.addPath(name);
+    
+    m_ui->workingDir->setUrl(current);
+}
+
 void ProjectSourcePage::setStatus(const QString& message)
 {
     KColorScheme scheme(QPalette::Normal);
