@@ -76,8 +76,9 @@ public:
     }
 };
 
-Session::Session( const QUuid& id )
-        : d( new SessionPrivate )
+Session::Session( const QUuid& id, QObject* parent )
+        : ISession(parent)
+        , d( new SessionPrivate )
 {
     d->id = id;
     d->initialize();
@@ -129,6 +130,7 @@ void Session::updateDescription()
     }
     
     d->config->group("").writeEntry( cfgSessionPrettyContentsEntry, prettyContents );
+    d->config->group("").sync();
 }
 
 QString Session::description() const
