@@ -114,6 +114,9 @@ private:
     KDevelop::Core* m_core;
     QTimer* m_hideToolTipTimer;
     QPointer<KDevelop::ActiveToolTip> m_tooltip;
+    // This is set to true while the working-set controller is forcing a working-set
+    // onto an area. We ignore the low-level feedback then, as we handle the switch on a higher level.
+    bool m_changingWorkingSet;
 };
 
 }
