@@ -40,7 +40,6 @@
 
 #include "view.h"
 #include "document.h"
-#include <qpointer.h>
 #include <QEvent>
 #include <QKeyEvent>
 #include "urldocument.h"
@@ -90,7 +89,7 @@ struct ContainerPrivate {
     KSqueezedTextLabel *fileNameCorner;
     QLabel *fileStatus;
     KSqueezedTextLabel *statusCorner;
-    QPointer<QWidget> leftCornerWidget;
+    QWeakPointer<QWidget> leftCornerWidget;
 };
 
 class UnderlinedLabel: public KSqueezedTextLabel {
@@ -183,7 +182,7 @@ Container::Container(QWidget *parent)
 
     connect(d->tabBar, SIGNAL(currentChanged(int)), this, SLOT(widgetActivated(int)));
     connect(d->tabBar, SIGNAL(tabCloseRequested(int)), this, SLOT(closeRequest(int)));
-    connect(d->tabBar, SIGNAL(tabMoved(int,int)), this, SLOT(tabMoved(int, int)));
+    connect(d->tabBar, SIGNAL(tabMoved(int,int)), this, SLOT(tabMoved(int,int)));
     connect(d->tabBar, SIGNAL(wheelDelta(int)), this, SLOT(wheelScroll(int)));
     connect(d->tabBar, SIGNAL(contextMenu(int,QPoint)), this, SLOT(contextMenu(int,QPoint)));
     connect(d->tabBar, SIGNAL(mouseMiddleClick(int)), this, SLOT(closeRequest(int)));
@@ -197,11 +196,12 @@ Container::Container(QWidget *parent)
 
 void Container::setLeftCornerWidget(QWidget* widget)
 {
-    if(d->leftCornerWidget == widget) {
+    if(d->leftCornerWidget.data() == widget) {
         if(d->leftCornerWidget)
-            d->leftCornerWidget->setParent(0);
+            d->leftCornerWidget.data()->setParent(0);
     }else{
-        delete d->leftCornerWidget;
+        delete d->leftCornerWidget.data();
+        d->leftCornerWidget.clear();
     }
     d->leftCornerWidget = widget;
     if(!widget)
@@ -319,7 +319,7 @@ void Container::documentTitleChanged(Sublime::Document* doc)
                 } else {
                     pretty = udoc->url().prettyUrl();
                 }
-                txt = txt + " (" + pretty + ")";
+                txt = txt + " (" + pretty + ')';
             }
             d->fileNameCorner->setText( txt );
             int tabIndex = d->stack->indexOf(it.key());
@@ -353,8 +353,13 @@ void Container::setCurrentWidget(QWidget* w)
     if (View *view = d->viewForWidget[w])
     {
         statusChanged(view);
-        statusIconChanged( view->document() );
-        documentTitleChanged( view->document() );
+        if (!d->tabBar->isVisible())
+        {
+            // repaint icon and document title only in tabbar-less mode
+            // tabbar will do repainting for us
+            statusIconChanged( view->document() );
+            documentTitleChanged( view->document() );
+        }
     }
 }
 
@@ -374,7 +379,9 @@ void Sublime::Container::removeWidget(QWidget *w)
         int widgetIdx = d->stack->indexOf(w);
         d->stack->removeWidget(w);
         d->tabBar->removeTab(widgetIdx);
-        if (d->tabBar->currentIndex() != -1) {
+        if (d->tabBar->currentIndex() != -1 && !d->tabBar->isVisible()) {
+            // repaint icon and document title only in tabbar-less mode
+            // tabbar will do repainting for us
             QWidget* w = widget( d->tabBar->currentIndex() );
             if( w ) {
                 statusIconChanged( d->viewForWidget[w]->document() );
@@ -425,7 +432,7 @@ void Container::tabMoved(int from, int to)
     d->viewForWidget[w]->notifyPositionChanged(to);
 }
 
-void Container::contextMenu( int currentTab, QPoint pos )
+void Container::contextMenu( int currentTab, const QPoint& pos )
 {
     KMenu menu;
 
@@ -469,9 +476,21 @@ void Container::contextMenu( int currentTab, QPoint pos )
 
 void Container::showTooltipForTab(int tab)
 {
-    emit tabToolTipRequested(viewForWidget(widget(tab)), QCursor::pos());
+    emit tabToolTipRequested(viewForWidget(widget(tab)), this, tab);
 }
 
+bool Container::isCurrentTab(int tab) const
+{
+    return d->tabBar->currentIndex() == tab;
+}
+
+QRect Container::tabRect(int tab) const
+{
+    return d->tabBar->tabRect(tab).translated(d->tabBar->mapToGlobal(QPoint(0, 0)));
+}
+
+
+
 }
 
 #include "container.moc"
