@@ -159,7 +159,7 @@ IdealButtonBarWidget::IdealButtonBarWidget(Qt::DockWidgetArea area,
     , _corner(0)
 {
     setContextMenuPolicy(Qt::CustomContextMenu);
-    setToolTip(i18n("Right click to add new tool views."));
+    setToolTip(i18nc("@info:tooltip", "Right click to add new tool views."));
 
     if (area == Qt::BottomDockWidgetArea)
     {
@@ -200,11 +200,11 @@ KAction *IdealButtonBarWidget::addWidget(const QString& title, IdealDockWidget *
     _widgets[action] = dock;
     connect(action, SIGNAL(toggled(bool)), this, SLOT(showWidget(bool)));
 
+    bool wasEmpty = actions().isEmpty();
     addAction(action);
-    // adymo: layout doesn't notice the addition of actions for some reason,
-    // enforce the invalidation
-    layout()->invalidate();
 
+    if(wasEmpty)
+        emit emptyChanged();
     return action;
 }
 
@@ -220,6 +220,11 @@ void IdealButtonBarWidget::removeAction(QAction * action)
     delete action;
 }
 
+bool IdealButtonBarWidget::isEmpty()
+{
+    return actions().isEmpty();
+}
+
 Qt::Orientation IdealButtonBarWidget::orientation() const
 {
     if (_area == Qt::LeftDockWidgetArea || _area == Qt::RightDockWidgetArea)
@@ -310,12 +315,14 @@ void IdealButtonBarWidget::actionEvent(QActionEvent *event)
                     if (item->widget() == button) {
                         action->disconnect(this);
                         delete layout()->takeAt(index);
-                        layout()->invalidate();
                         break;
                     }
                 }
             }
         }
+        if(layout()->isEmpty()) {
+            emit emptyChanged();
+        }
     } break;
 
     case QEvent::ActionChanged: {
@@ -568,7 +575,7 @@ void IdealController::addView(Qt::DockWidgetArea area, View* view)
     QString dockObjectName = view->document()->title();
     // support different configuration for same docks opened in different areas
     if (m_mainWindow->area())
-        dockObjectName += "_" + m_mainWindow->area()->objectName();
+        dockObjectName += '_' + m_mainWindow->area()->objectName();
 
     dock->setObjectName(dockObjectName);
 
@@ -619,7 +626,6 @@ void IdealController::addView(Qt::DockWidgetArea area, View* view)
         action->setShortcut(shortcut);
 
         m_docks->addAction(action);
-        bar->show();
         connect(dock, SIGNAL(close()), action, SLOT(toggle()));
     }
 
