@@ -132,7 +132,7 @@ void CommandExecutor::start()
     } else {
         QStringList arguments;
         Q_FOREACH( const QString &a, d->m_args ) arguments << KShell::quoteArg( a );
-        d->m_process->setShellCommand( d->m_command + " " + arguments.join( " " ) );
+        d->m_process->setShellCommand( d->m_command + ' ' + arguments.join( " " ) );
     }
 
     d->m_process->start();
